@@ -7,12 +7,11 @@ DISCLAIMER - USE AT YOUR OWN RISK.
 Project version and meta informations.
 """
 
-__version__ = "2.4.2"
+__version__ = "2.4.4"
 __title__ = "wpwatcher"
-__description__ = "wpwatcher - WordPress Watcher is a Python wrapper for WPScan that manages scans on multiple sites and reports by email and syslog"
+__description__ = "WordPress Watcher - Automating WPScan to scan and report vulnerable Wordpress sites"
 __author__ = "Florian Roth, Tristan Landes"
 __author_email__ = ""
 __license__ = "Apache License 2.0"
 __url__ = "https://github.com/tristanlatr/WPWatcher"
 __keywords__ = "wpscan auto multiple bulk batch scan wordpress email report alerts warnings service automate mass vulnerable sites asynchronous syslog"
-
